en constant

Map<String, dynamic> const en

Implementation

static const Map<String,dynamic> en = {
  "onboarding": {
    "notifications": {
      "action": "Allow notifications",
      "denied": {
        "description": "No worries! We will make sure to respect your tranquility.",
        "intro": "Notifications have been disabled.",
        "notes": "Please note that you can always enable notifications in your device settings."
      },
      "description": "We commit to sending you only relevant and useful notifications.",
      "granted": {
        "description": "You will now receive updates and notifications from us.",
        "intro": "Notifications have been enabled.",
        "notes": "Please note that you can change this setting in your device settings."
      },
      "intro": "Stay informed about the latest updates, news, and important information.",
      "notes": "Please note that you have the option to change your notification preferences at any time in your device settings.",
      "title": "Notifications"
    },
    "personalized_ads": {
      "action": "Enable personalized ads",
      "denied": {
        "description": "We respect your choice. You will see generic ads instead.",
        "intro": "Personalized ads have been disabled.",
        "notes": "Please note that you can always enable tracking in your device settings."
      },
      "description": "We respect your privacy and commit to using your information solely for the purpose of enhancing your experience and presenting relevant advertisements.",
      "granted": {
        "description": "You will see ads tailored to your interests.",
        "intro": "Personalized ads have enabled.",
        "notes": "Please note that you can change this setting in your device settings."
      },
      "intro": "The application will request your consent to track your data. This will help us provide you with personalized ads based on your interests, as well as an optimized user experience. Ads allow us to keep our content free. We invite you to allow this access to continue supporting free content.",
      "title": "Personalized Ads"
    },
    "restore_premium": {
      "action": "Restore Purchases",
      "intro": "If you previously acquired the premium version, we recommend restoring your purchases to regain access to all your premium features.",
      "notes": "Please note that you have the option to restore your purchases at any time.",
      "title": "Restore Premium Features"
    },
    "user_country": {
      "action": "Choose Your Country",
      "intro": "Select your country to customize content based on your location.",
      "notes": "Please note that you have the option to change your country at any time in the settings.",
      "title": "Country"
    },
    "user_currency": {
      "action": "Choose Your Currency",
      "intro": "Select your preferred currency to display prices in your local currency.",
      "notes": "Please note that you have the option to change your currency at any time in the settings.",
      "title": "Currency"
    },
    "welcome_finance_traders": {
      "description": "Take control and trade with confidence and peace of mind!",
      "intro": "Improve your trading strategy with our risk management tools to maximize your results.",
      "title": "Welcome, Traders"
    },
    "welcome_gain_loss_calculator": {
      "intro": "Discover your potential earnings at a glance and make informed decisions to maximize your opportunities."
    },
    "welcome_vat": {
      "description": "Simply enter the net amount, select your rate, and let the application do the rest.",
      "intro": "Quickly and accurately define the VAT amounts specific to your region."
    }
  }
};